"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenPartition = void 0;
/**
 * @class TokenPartition
 * @package models
 * @since v0.1.0
 * @description Model that describes partitions of tokens. A partition
 *              is created around an \a owner address (32 bytes) and
 *              an \a amount (1-8 bytes) and a \a name
 */
class TokenPartition {
    /**
     * Constructor for TokenIdentifier objects
     *
     * @param {UInt64} id
     */
    constructor(
    /**
     * @description The partition name
     */
    name, 
    /**
     * @description The partition owner
     */
    owner, 
    /**
     * @description The partition account
     */
    account, 
    /**
     * @description The amount of the partition
     */
    amount) {
        this.name = name;
        this.owner = owner;
        this.account = account;
        this.amount = amount;
    }
    /**
     * Comparison operator
     *
     * @param {TokenPartition} rhs
     * @return {boolean}
     */
    equals(rhs) {
        return this.owner.equals(rhs.owner)
            && this.account.publicKey === rhs.account.publicKey
            && this.account.address.equals(rhs.account.address)
            && this.amount === rhs.amount
            && this.name === rhs.name;
    }
}
exports.TokenPartition = TokenPartition;
